clear all
close all

models={ 'Original' 'Proposed'};

RefractiveErrors = 0;
ExternalLens = -1;
AccomRange = 10;

tLens = 2; % when to apply the lens
tmax = 20;% s how long to simulate for

DistanceDemand = 0;

cycloplegia = [0 0.5 1]; % no, partial, full cycloplegia
lst = {'-' '--' ':'};
str0 = {'Normal viewing' 'Partial cycloplegia' 'Complete cycloplegia'};

PlotColors

figure('pos',[  60   245   1400   454])
for jmod=1:2
    subplot(1,2,jmod)
    modelname = ['SimplifiedAccommodationModel_' models{jmod}];
    exptname = ['Expt_'  models{jmod}];
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    load_system(modelname )
    workspace = get_param(modelname,'ModelWorkspace');
    restfocus = getVariable(workspace,'NeuralBias');
    setVariablePart(workspace,'AccomRange.Value',AccomRange)
    senslat = getVariablePart(workspace,'SensoryLatency.Value');
    motlat = getVariablePart(workspace,'MotorLatency.Value');
    latency = senslat+motlat;
    
    
    %%%% Load in model and set it up for the simulation:
    load_system(exptname)
    
    
    % Set up the demand
    set_param([exptname '/StepUp'],'Time','200');
    set_param([exptname '/StepUp'],'Before',num2str(DistanceDemand));
    set_param([exptname '/StepUp'],'After',num2str(DistanceDemand));
    set_param([exptname '/StepDown'],'Time','200');
    set_param([exptname '/StepDown'],'Before','0');
    set_param([exptname '/StepDown'],'After','-2');
    % Ensure  correction
    set_param([exptname '/External Lens'],'After',num2str(ExternalLens));
    set_param([exptname '/External Lens'],'Time',num2str(tLens));
    set_param([exptname '/External Lens'],'Before','0');
    
    
    demand = [exptname '/Distance'];
    
    % Turn off data-logging:
    pH = find_system(exptname, 'LookUnderMasks','all','FindAll', 'on', 'DataLogging', 'on');
    for x=1:length(pH)
        set_param(pH(x), 'DataLogging', 'off');
    end
    % Turn it back on for accommodation only:
    ph=get_param([exptname '/Observer'],'PortHandles');
    set_param(ph.Outport(1),'DataLogging','on');
    
    set_param(exptname,'UnitsInconsistencyMsg' , 'none' )
    set_param(exptname,'SolverType' , 'Fixed-step' )
    set_param(exptname,'FixedStep' , '1e-3' )
    set_param(modelname,'SolverType' , 'Fixed-step' )
    set_param(modelname,'FixedStep' , '1e-3' )
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % Simulate the steady-state response to different accommodative
    % demands, for different ages
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
    % Set the model refractive error to the specified value
    setVariablePart(workspace,'RefractiveError.Value',RefractiveErrors)
    
    for jcyc=1:3 % normal viewing, then cycloplegia
        set_param([exptname '/Cycloplegia'],'Value',num2str(cycloplegia(jcyc)));
        
        
        % Run simulation for 45s with this accommodation, saving result:
        out1 = sim(exptname,'StartTime',num2str(-tmax),'StopTime',num2str(tmax),...
            'SaveFormat', 'Dataset', ...
            'SignalLogging','on','SignalLoggingName','logsout');
        
        d=getElement(out1.logsout,'distance demand');
        hD=plot(d.Values.Time,d.Values.Data,'col',colDistDem,'linew',4)
        hold on
        deff=getElement(out1.logsout,'effective demand');
        hDeff=plot(deff.Values.Time,deff.Values.Data,'col',colEffDem,'linew',2,'linest',lst{jcyc})
        op=getElement(out1.logsout,'Ocular Power');
        hOcPow = plot(op.Values.Time,op.Values.Data,'linew',2,'col',colOcPow,'linest',lst{jcyc});
        f=getElement(out1.logsout,'fast signal');
        hcyc(jcyc) = plot(f.Values.Time,f.Values.Data,'linew',3,'col',colInteg,'linest',lst{jcyc});
        hfast= plot(f.Values.Time,f.Values.Data,'linew',3,'col',colInteg,'linest',lst{jcyc});
        
        xlim([0 tmax])
        plot(tLens*[1 1],ylim,'k--')
        plot((tLens+latency)*[1 1],ylim,'k:')
        
        if jcyc==1 && jmod==1
            l=legend(gca,[ hDeff hfast hOcPow],{ 'effective demand' 'integrator output' 'ocular power' },'location','northwest','fontsize',fs,'AutoUpdate','off');
        end
        h =0.1; w = 0.3;
        % compute change from t=0 to end of simulation
        jt0 = find(deff.Values.Time==0);
        deltaEff = deff.Values.Data(end)-deff.Values.Data(jt0);
        str1 = sprintf('Change in effective demand = %2.1fD\n',deltaEff);
        deltaFast = f.Values.Data(end)-f.Values.Data(jt0);
        str3 = sprintf('Change in integrator output = %2.1fD\n',deltaFast);
        str4 = sprintf('Stimulus AC/A ratio : %2.1f',deltaFast/deltaEff);
        p=get(gca,'Position');
        dim = [(p(1)+p(3)-0.1) (p(2)+p(4)-1.5*h-2*h*jcyc/2) w h];
        annotation('textbox',dim,'String',[ sprintf('%s\n',str0{jcyc})   str4],'FitBoxToText','on','backgroundcol','w');
        
        
    end % nextcylocloplegia
    title({sprintf('%1.0fD lens at t=%1.0fs with/without cycloplegia',ExternalLens,tLens) ; [repmat('i',1,jmod) ') ' models{jmod} ' model']},'fontsize',18,'units','norm')
    text(-0.1,0.95,repmat('i',1,jmod),'fontweight','bold','fontsize',18,'units','norm')
    
    xlabel('time (s)')
    set(gca,'fontsize',14)
    % Make new axis for second legend
    if jmod==2
%        title({' '; [models{jmod} ' model']},'fontsize',18,'units','norm')
        legend(hcyc,str0,'location','northwest','fontsize',fs+1,'AutoUpdate','off')
    end
    % Close the model, abandoning all changes made
    bdclose(exptname)
    
end
print(gcf,'Figure14.tif','-r400','-dtiff');



