clear all
close all

models={ 'Original' 'Proposed' 'Alternative'};

RefractiveErrors = 0;
AccomRange = 10;
BlurThreshold = 0.4; % For estimating near point

tmax = 10;% s how long to simulate for
ExternalLens = -1; % whern getting ACA ratio
tLens = 2; % when to apply the lens

DistanceDemand = [0:0.2:8 ]; % NB this is slow - increase spacing for a faster run

cycloplegia = [0 0.4 0.6 0.8 0.9 1]; % no, partial, full cycloplegia

PlotColors

data = readtable('ChristofersonOgleFig4.xlsx');

jmod=2% We plot this for proposed new model only - but you could change this line if others are required

modelname = ['SimplifiedAccommodationModel_' models{jmod}];
exptname = ['Expt_'  models{jmod}];


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
load_system(modelname )
workspace = get_param(modelname,'ModelWorkspace');
NeuralBias = getVariable(workspace,'NeuralBias');
setVariablePart(workspace,'AccomRange.Value',AccomRange)
senslat = getVariablePart(workspace,'SensoryLatency.Value');
motlat = getVariablePart(workspace,'MotorLatency.Value');
latency = senslat+motlat;



%%%% Load in model and set it up for the simulation:
load_system(exptname)

figure('pos',[  160+jmod*100   445    1029         398])



demand = [exptname '/Distance'];

% Turn off data-logging:
pH = find_system(exptname, 'LookUnderMasks','all','FindAll', 'on', 'DataLogging', 'on');
for x=1:length(pH)
    set_param(pH(x), 'DataLogging', 'off');
end
% Turn it back on for accommodation only:
ph=get_param([exptname '/Observer'],'PortHandles');
set_param(ph.Outport(1),'DataLogging','on');

set_param(exptname,'UnitsInconsistencyMsg' , 'none' )
set_param(exptname,'SolverType' , 'Fixed-step' )
set_param(exptname,'FixedStep' , '1e-3' )
set_param(modelname,'SolverType' , 'Fixed-step' )
set_param(modelname,'FixedStep' , '1e-3' )

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Simulate the steady-state response to different accommodative
% demands, for different ages
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Set the model refractive error to the specified value
setVariablePart(workspace,'RefractiveError.Value',RefractiveErrors)


for jcyc=1:length(cycloplegia) % normal viewing, then cycloplegia
    
    % Set up the demand
    set_param([exptname '/StepUp'],'Time','200');
    set_param([exptname '/StepDown'],'Time','200');
    set_param([exptname '/StepDown'],'Before','0');
    set_param([exptname '/StepDown'],'After','-2');
    % Ensure no correction
    set_param([exptname '/External Lens'],'After','0');
    set_param([exptname '/External Lens'],'Time','0');
    set_param([exptname '/External Lens'],'Before','0');
    set_param([exptname '/Cycloplegia'],'Value',num2str(cycloplegia(jcyc)));
    
    % First, simulate constant demand and see where the steady-state
    % is:
    for jD=1:length(DistanceDemand)
        set_param([exptname '/StepUp'],'Before',num2str(DistanceDemand(jD)));
        set_param([exptname '/StepUp'],'After',num2str(DistanceDemand(jD)));
        
        % Run simulation  saving result:
        out1 = sim(exptname,'StartTime',num2str(-tmax),'StopTime',num2str(tmax),...
            'SaveFormat', 'Dataset', ...
            'SignalLogging','on','SignalLoggingName','logsout');
        
        op=getElement(out1.logsout,'Ocular Power');
        OcPow(jD,jcyc) = op.Values.Data(end);
        if cycloplegia(jcyc)==0
            hlab{jcyc} = 'Normal viewing (CP=0)';
        elseif cycloplegia(jcyc)==1
            hlab{jcyc} = 'Complete cycloplegia (CP=1)';
        else
            hlab{jcyc} = sprintf('Partial cycloplegia (CP=%3.1f)',cycloplegia(jcyc));
        end
        
    end % next demand
    % Extrapolate and plot
    D = [min(DistanceDemand):range(DistanceDemand)/100:max(DistanceDemand)];
    subplot(1,2,1)
    hcyc(jcyc)=plot(DistanceDemand,OcPow(:,jcyc),'-','linew',2);
    col = get(hcyc(jcyc),'col');
    ylabel('accommodative response (D)')
    hold on
    title(['Effect of cycloplegia: ' models{jmod} ' model'],'fontsize',18,'units','norm')
    
    subplot(1,2,2)
    abserr = interp1(DistanceDemand,abs(OcPow(:,jcyc)'-DistanceDemand),D);
    hcyc2(jcyc)=plot(D,abserr,'-','linew',2,'color',col);
    ylabel('defocus error (D)')
    hold on
    % Find near point, ie maximum demand for which defocus error is
    % less than threshold
    NearPoint(jcyc) = D(max(find(abserr<BlurThreshold)));
    plot( NearPoint(jcyc),BlurThreshold,'x','col',col,'linew',2,'markersize',14 );
    
    %%%%%%%%%%%%%%%%%%%%%%%%
    % ACA ratio
    % Now, simulate adding in an external lens and look at the change
    % in integrator output
    set_param([exptname '/StepUp'],'Before','0');
    set_param([exptname '/StepUp'],'After','0');
    % Ensure  correction
    set_param([exptname '/External Lens'],'After',num2str(ExternalLens));
    set_param([exptname '/External Lens'],'Time',num2str(tLens));
    set_param([exptname '/External Lens'],'Before','0');
    % Run simulation
    out1 = sim(exptname,'StartTime',num2str(-tmax),'StopTime',num2str(tmax*2),...
        'SaveFormat', 'Dataset', ...
        'SignalLogging','on','SignalLoggingName','logsout');
    deff=getElement(out1.logsout,'effective demand');
    f=getElement(out1.logsout,'fast signal');
    % compute change from t=0 to end of simulation
    jt0 = find(deff.Values.Time==0);
    deltaEff = deff.Values.Data(end)-deff.Values.Data(jt0);
    deltaFast = f.Values.Data(end)-f.Values.Data(jt0);
    ACAratio(jcyc) = deltaFast/deltaEff;
    
    
end % next cyloplegia
save PlotNearpointCycloplegia
subplot(1,2,1)
plot(xlim,xlim,'k-')
plot(ylim,ylim,'k-')
for j=1:2
    subplot(1,2,j)
    xlabel('accommodative demand (D)')
    text(-0.2,0.95,char(64+j),'fontweight','bold','fontsize',18,'units','norm')
end
legend(hcyc,hlab,'location','northwest','fontsize',fs)
print(gcf,'Figure15.tif','-r400','-dtiff');

% Now plot near point and ACA ratio
figure('pos',[  60+jmod*100   445   1385   398])
subplot(1,3,1)
hNP = plot(cycloplegia,NearPoint,'r','linew',2);
xlabel('Value of Cycloplegia parameter')
ylabel('Subjective near point (D)')
subplot(1,3,2)
hACA = plot(cycloplegia,ACAratio,'b','linew',2);
xlabel('Value of Cycloplegia parameter')
ylabel('Stimulus AC/A ratio')

%legend([hNP hACA],{'Near point (D)' 'AC/A ratio'},'location','northwest','fontsize',fs)
%title(['Effect of cycloplegia: ' models{jmod} ' model'],'fontsize',18,'units','norm')
subplot(1,3,3)
plot(NearPoint,ACAratio./ACAratio(cycloplegia==0),'col',[0.5 0. 0.5],'linew',2)
hold on
plot(data.NearPoint,data.ACARatio./data.ACARatio(data.Hours==24),'o','col',[0.5 0. 0.5],'markerfacecol',[0.5 0. 0.5],'linew',2)
xlabel(sprintf('Near point (D, %3.1fD blur threshold)',BlurThreshold))
ylabel('AC/A ratio relative to baseline')
axis tight
for j=1:3
    subplot(1,3,j)
    text(-0.3,1.05,char(64+j),'fontweight','bold','fontsize',18,'units','norm')
    set(gca,'fontsize',16)
end
print(gcf,'Figure16.tif','-r400','-dtiff');

% Close the model, abandoning all changes made
bdclose(exptname)

