clear all
close all

models={ 'Original' 'Proposed' 'Alternative'};

RefractiveErrors = [-2 -1 0 1 2];
AccomRange = 4;
Fogging = +3;
tLens=5;

for jmod=1:2
    
    modelname = ['SimplifiedAccommodationModel_' models{jmod}];
    exptname = ['Expt_'  models{jmod}];
    
    tStepUp = 10; % time at which demand steps up
    tStepDown = 20; % time at which demand steps back down
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % Plot rest focus
    load_system(modelname )
    workspace = get_param(modelname,'ModelWorkspace');
    NeuralBias = getVariable(workspace,'NeuralBias');
    setVariablePart(workspace,'AccomRange.Value',AccomRange)
    senslat = getVariablePart(workspace,'SensoryLatency.Value');
    motlat = getVariablePart(workspace,'MotorLatency.Value');
    latency = senslat+motlat;
    
    
    %%%% Load in model and set it up for the simulation:
    load_system(exptname)
    
    % zero demand
    set_param([exptname '/StepUp'],'Time','0');
    set_param([exptname '/StepUp'],'Before','0');
    set_param([exptname '/StepUp'],'After','0');
    set_param([exptname '/StepDown'],'Time','0');
    set_param([exptname '/StepDown'],'Before','0');
    set_param([exptname '/StepDown'],'After','0');
    % Apply fogging lenses
    set_param([exptname '/External Lens'],'After',num2str(Fogging));
    set_param([exptname '/External Lens'],'Time',num2str(tLens));
    set_param([exptname '/External Lens'],'Before','0');
    
    
    demand = [exptname '/Distance'];
    
    % Turn off data-logging:
    pH = find_system(exptname, 'LookUnderMasks','all','FindAll', 'on', 'DataLogging', 'on');
    for x=1:length(pH)
        set_param(pH(x), 'DataLogging', 'off');
    end
    % Turn it back on for accommodation only:
    ph=get_param([exptname '/Observer'],'PortHandles');
    set_param(ph.Outport(1),'DataLogging','on');
    
    set_param(exptname,'UnitsInconsistencyMsg' , 'none' )
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % Simulate the steady-state response to different accommodative
    % demands, for different ages
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    figure('pos',[  160+jmod*100   245   695   454])
    
    for jRE = [1:length(RefractiveErrors)]
        
        % Set the model refractive error to the specified value
        setVariablePart(workspace,'RefractiveError.Value',RefractiveErrors(jRE))
        
        % Run once without cycloplegia:
        set_param([exptname '/Cycloplegia'],'Value','0');
        % Run simulation for 45s with this accommodation, saving result:
        out1 = sim(exptname,'StartTime','-10','StopTime','10',...
            'SaveFormat', 'Dataset', ...
            'SignalLogging','on','SignalLoggingName','logsout');
        
        % Read off accomm:
        a=getElement(out1.logsout,'Ocular Power');
        time{jRE} = a.Values.Time;
        A{jRE} = a.Values.Data;
        
        hlabsD{jRE} = sprintf('%1.0fD %s',RefractiveErrors(jRE),GetOpe(RefractiveErrors(jRE)))
        
        hlab(jRE) = plot(time{jRE},A{jRE},'linew',2,'linest','-','col',GetRECol(RefractiveErrors(jRE)));
        hold on
        hnorm = plot(time{jRE},A{jRE},'linew',2,'linest','-','col',GetRECol(RefractiveErrors(jRE)));
        
        % Now run again with partial cycloplegia:
        set_param([exptname '/Cycloplegia'],'Value','0.5');
        outcyc = sim(exptname,'StartTime','-10','StopTime','10',...
            'SaveFormat', 'Dataset', ...
            'SignalLogging','on','SignalLoggingName','logsout');
        a=getElement(outcyc.logsout,'Ocular Power');
        time{jRE} = a.Values.Time;
        A{jRE} = a.Values.Data;
        hcycP=plot(time{jRE},A{jRE},'linew',2,'linest','--','col',GetRECol(RefractiveErrors(jRE))); % Plot in same col but with dashed line
        
         % Now run again with full cycloplegia:
        set_param([exptname '/Cycloplegia'],'Value','1');
        outcyc = sim(exptname,'StartTime','-10','StopTime','10',...
            'SaveFormat', 'Dataset', ...
            'SignalLogging','on','SignalLoggingName','logsout');
        a=getElement(outcyc.logsout,'Ocular Power');
        time{jRE} = a.Values.Time;
        A{jRE} = a.Values.Data;
        hcycF=plot(time{jRE},A{jRE},'linew',2,'linest',':','col',GetRECol(RefractiveErrors(jRE))); % Plot in same col but with dotted line
        
        
    end
    xlim([0 10])
    set(gca,'fontsize',16)
    
    xlabel('time (s)')
    ylabel('Ocular power (D)')
    
    plot([1 1]*tLens,ylim,'k--')
    text(tLens,min(ylim)-0.1,'Fogging','units','data','vert','top','horiz','cen')
    
    legend(hlab,hlabsD,'location','northwest','fontsize',16)
    title(['Effect of cycloplegia; ' models{jmod} ' model'],'fontsize',16,'units','norm')
    
    % Make new axis for second legend
    ax2=axes('pos',get(gca,'position'),'visible','off')
    legend(ax2,[hnorm hcycP hcycF],{'Normal viewing' 'Partial cycloplegia' 'Full cycloplegia'},'location','northeast','fontsize',16)
    
    % Close the model, abandoning all changes made
    bdclose(exptname)
    
    print(gcf,['Fig_OcularPowerCycloplegia' models{jmod} '.tif'],'-r400','-dtiff');

end % next model


print(gcf,'Figure13.tif','-r400','-dtiff');



