clear all
close all

models={ 'Original' 'Proposed'};

RefractiveErrors = [2 0  -2];
AccomRange = 4;

PlotColors
figure('pos',[ 60   245   1400   454])
for jmod=1:2
    
    modelname = ['SimplifiedAccommodationModel_' models{jmod}];
    exptname = ['Expt_'  models{jmod}];
    
    tStepUp = 10; % time at which demand steps up
    tStepDown = 20; % time at which demand steps back down
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
    load_system(modelname )
    workspace = get_param(modelname,'ModelWorkspace');
    restfocus = getVariable(workspace,'NeuralBias');
    setVariablePart(workspace,'AccomRange.Value',AccomRange)
    senslat = getVariablePart(workspace,'SensoryLatency.Value');
    motlat = getVariablePart(workspace,'MotorLatency.Value');
    latency = senslat+motlat;
    
    
    %%%% Load in model and set it up for the simulation:
    load_system(exptname)
    
    % Set up the demand
    set_param([exptname '/StepUp'],'Time',num2str(tStepUp));
    set_param([exptname '/StepUp'],'Before','0');
    set_param([exptname '/StepUp'],'After','3');
    set_param([exptname '/StepDown'],'Time',num2str(tStepDown));
    set_param([exptname '/StepDown'],'Before','0');
    set_param([exptname '/StepDown'],'After','-2');
    % Ensure  no corrective lenses or cyclopelgia
    set_param([exptname '/External Lens'],'After','0');
    set_param([exptname '/External Lens'],'Time','-1000');
    set_param([exptname '/External Lens'],'Before','0');
    set_param([exptname '/Cycloplegia'],'Value','0');

    
    demand = [exptname '/Distance'];
    
    % Turn off data-logging:
    pH = find_system(exptname, 'LookUnderMasks','all','FindAll', 'on', 'DataLogging', 'on');
    for x=1:length(pH)
        set_param(pH(x), 'DataLogging', 'off');
    end
    % Turn it back on for accommodation only:
    ph=get_param([exptname '/Observer'],'PortHandles');
    set_param(ph.Outport(1),'DataLogging','on');
    
    set_param(exptname,'UnitsInconsistencyMsg' , 'none' )
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % Simulate the steady-state response to different accommodative
    % demands, for different ages
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    subplot(1,2,jmod)
    
    for jRE = [1:length(RefractiveErrors)]
        
        % Set the model refractive error to the specified value
        setVariablePart(workspace,'RefractiveError.Value',RefractiveErrors(jRE))
        
        
        % Run simulation for 45s with this accommodation, saving result:
        out1 = sim(exptname,'StartTime','-10','StopTime','30',...
            'SaveFormat', 'Dataset', ...
            'SignalLogging','on','SignalLoggingName','logsout');
        
        % Read off accomm:
        a=getElement(out1.logsout,'Ocular Power');
        time{jRE} = a.Values.Time;
        A{jRE} = a.Values.Data;
        
        hlabsD{jRE} = sprintf('%1.0fD %s',RefractiveErrors(jRE),GetOpe(RefractiveErrors(jRE)))
        
    end

    
    for jRE = [1:length(RefractiveErrors)]
        hlab(jRE) = plot(time{jRE},A{jRE},'linew',4-0.5*jRE,'col',GetRECol(RefractiveErrors(jRE))); % Make subsequent lines thinner
        hold on
    end
    plot(tStepUp*[1 1],ylim,'k--','linew',2)
    plot(tStepDown*[1 1],ylim,'k--','linew',2)
    plot((tStepUp+latency)*[1 1],ylim,'k:','linew',2)
    plot((tStepDown+latency)*[1 1],ylim,'k:','linew',2)
    xlabel('time (s)')
    ylabel('Ocular power (D)')
    % Plot demand
    ylim([0 3.2])
    xlim([0 30])
    d=getElement(out1.logsout,'distance demand');
    hd=plot(d.Values.Time,d.Values.Data,'col',colEffDem,'linew',3);

    title({'Various refractive errors'; [ repmat('i',1,jmod) ') ' models{jmod} ' model']},'fontsize',18,'units','norm')
    set(gca,'fontsize',14)
    text(-0.25,1.05,repmat('i',1,jmod),'fontweight','bold','fontsize',18,'units','norm')
    % Close the model, abandoning all changes made
    bdclose(exptname)

    
end
l=legend([hd hlab],{'effective demand' hlabsD{:}},'location','northeast')
set(l,'pos',[0.45   0.69   0.13   0.2])
print(gcf,'Figure7.tif','-r400','-dtiff');



