clear all
close all

models={ 'Original' 'Proposed'};

Demand = 4;
RefractiveErrors = -4;
ExternalLens = +4;
AccomRange = 6;
tLens = 2; % time at whi#ch lens is applied
tmax = 6;%s how long to simulate for

figure('pos',[ 60   100   1400   600])
for jmod=1:2
    
    modelname = ['SimplifiedAccommodationModel_' models{jmod}];
    exptname = ['Expt_'  models{jmod}];
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    load_system(modelname )
    workspace = get_param(modelname,'ModelWorkspace');
    restfocus = getVariable(workspace,'NeuralBias');
    setVariablePart(workspace,'AccomRange.Value',AccomRange)
    senslat = getVariablePart(workspace,'SensoryLatency.Value');
    motlat = getVariablePart(workspace,'MotorLatency.Value');
    latency = senslat+motlat;
    
    
    %%%% Load in model and set it up for the simulation:
    load_system(exptname)
    
    % Set up the demand - just keep the distance constant at 0D:
    set_param([exptname '/StepUp'],'Time','0');
    set_param([exptname '/StepUp'],'Before',num2str(Demand));
    set_param([exptname '/StepUp'],'After',num2str(Demand));
    set_param([exptname '/StepDown'],'Time','200');
    set_param([exptname '/StepDown'],'Before','0');
    set_param([exptname '/StepDown'],'After','0');
    % Apply a lens at t=tLens:
    set_param([exptname '/External Lens'],'After',num2str(ExternalLens));
    set_param([exptname '/External Lens'],'Time',num2str(tLens));
    set_param([exptname '/External Lens'],'Before','0');
    set_param([exptname '/Cycloplegia'],'Value','0');
    
    demand = [exptname '/Distance'];
    
    % Turn off data-logging:
    pH = find_system(exptname, 'LookUnderMasks','all','FindAll', 'on', 'DataLogging', 'on');
    for x=1:length(pH)
        set_param(pH(x), 'DataLogging', 'off');
    end
    % Turn it back on for accommodation only:
    ph=get_param([exptname '/Observer'],'PortHandles');
    set_param(ph.Outport(1),'DataLogging','on');
    
    set_param(exptname,'UnitsInconsistencyMsg' , 'none' )
    set_param(exptname,'SolverType' , 'Fixed-step' )
    set_param(exptname,'FixedStep' , '1e-3' )
    set_param(modelname,'SolverType' , 'Fixed-step' )
    set_param(modelname,'FixedStep' , '1e-3' )
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % Simulate the steady-state response to different accommodative
    % demands, for different ages
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
    % Set the model refractive error to the specified value
    setVariablePart(workspace,'RefractiveError.Value',RefractiveErrors)
    
    
    % Run simulation for 45s with this accommodation, saving result:
    out1 = sim(exptname,'StartTime','-10','StopTime',num2str(tmax),...
        'SaveFormat', 'Dataset', ...
        'SignalLogging','on','SignalLoggingName','logsout');
    
    PlotSignalsScript
    % Draw on times when things change:
    for jplot=1:2
        subplot(2,2,jmod+2*(jplot-1))
        plot((tLens+latency)*[1 1],ylim,'k:')
        plot(tLens*[1 1],ylim,'k--')
        
    end
    subplot(2,2,jmod)
    title({sprintf('%dD %s, %dD lens applied at t=%ds',RefractiveErrors,GetOpe(RefractiveErrors),ExternalLens,tLens) ; sprintf('%s) %s model',repmat('i',1,jmod),models{jmod})},'fontsize',18,'units','norm')
    
    % Close the model, abandoning all changes made
    bdclose(exptname)
    
end
% Adjust legend location:
set(l1,'pos',[0.4 0.7 0.12 0.15])
set(l2,'pos',[0.35 0.23 0.2 0.15])
print(gcf,'Figure10.tif','-r400','-dtiff');



